import QtQuick 1.1

Item {
    id: root

    property string bugType: "ant"
    property int bugX
    property int bugY
    property real bugRotation: 0
    property real bugDistance: 10
    property real bugSpeed: 10
    property int bugStrength: 1
    property int bugImageIndex: 1
    property bool canBeBurned: true

    property bool _burning: false
    property bool _killed: false

    x: bugX
    y: bugY
    width: 40 * graphicsScale
    height: 40 * graphicsScale

    function heating() {
        if (_burning || _killed) return;

        if (canBeBurned) {
            bugStrength--;
            if (bugStrength <= 0) burn();
        }
    }

    function burn() {
        root._burning = true;

        if (world.currentLightInQueue === 0) {
            world.light1Pos = Qt.point((root.x + root.width/2) / mainView.width, 1.0 - (root.y + root.height/2) / mainView.height);
            world.animateLight1();
        } else {
            world.light2Pos = Qt.point((root.x + root.width/2) / mainView.width, 1.0 - (root.y + root.height/2) / mainView.height);
            world.animateLight2();
        }
        world.currentLightInQueue = (world.currentLightInQueue === 0) ? 1 : 0

        // Move down so this bug doesn't come first with childAt()
        root.z = -1;
        burnAnimation.restart();
        world.burnEffects.burn(root);

        coreLib.addScore(root.bugSpeed);
    }


    SequentialAnimation {
        id: burnAnimation
        paused: running ? _burning && gamePaused : false
        ParallelAnimation {
            PropertyAnimation {
                target: bugImage
                property: "opacity"
                to: 0
                duration: 1000
            }
            PropertyAnimation {
                target: bugImageBurnt
                property: "opacity"
                to: 1.0
                duration: 1000
            }
            PropertyAnimation {
                target: root
                property: "bugRotation"
                to: bugRotation + (30 - Math.random() * 60);
                duration: 2000
            }
        }
        ScriptAction {
            script: {
                root._burning = false;
                root._killed = true;
                //root.destroy();
                // TODO: Clean the item so that memory consumption is minimum when bug has burned
            }
        }
    }

    Image {
        id: bugImageBurnt
        source: "images/" + bugType + "_x.png"
        anchors.centerIn: parent
        smooth: true
        scale: graphicsScale
        rotation: root.bugRotation
        opacity: 0
    }
}
