import QtQuick 1.1

AbstractBug {
    id: root

    property real movingDuration: 10000

    Component.onCompleted: {
        if (bugType == "ant") {
            root.bugSpeed = 3;
            root.bugStrength = 4;
        } else if (bugType == "ladybug") {
            root.bugSpeed = 10;
            root.bugStrength = 20;
        } else if (bugType == "crab") {
            root.bugSpeed = 12;
            root.bugStrength = 25;
        } else if (bugType == "beetle") {
            root.bugSpeed = 8;
            root.bugStrength = 25;
        }
        root.movingDuration = bugDistance * currentGameSpeed * bugSpeed;
    }

    ParallelAnimation {
        running: true
        paused: running ? gamePaused || root._killed || root._burning : false
        PropertyAnimation {
            target: root
            property: "y"
            from: bugY
            to: worldHeight/2 - root.height/2
            duration: root.movingDuration
        }
        PropertyAnimation {
            target: root
            property: "x"
            from: bugX
            to: worldWidth/2 - root.width/2
            duration: root.movingDuration
        }
        onRunningChanged: {
            if (!running &&!root._burning && !root._killed && !gamePaused && gameOn) {
                coreLib.gameOver();
            }
        }
    }

    Image {
        id: bugImage
        source: "images/" + bugType + "_" + root.bugImageIndex + ".png"
        anchors.centerIn: parent
        smooth: true
        scale: graphicsScale
        rotation: root.bugRotation

        Timer {
            running: !_burning && !gamePaused && !root._killed
            repeat: true
            interval: 200
            onTriggered: {
                if (root.bugImageIndex < 8 && bugType == "crab" || root.bugImageIndex < 4 && bugType != "crab")
                    root.bugImageIndex++;
                else
                    root.bugImageIndex = 1;
            }
        }
    }

}
