import QtQuick 1.1
import Qt.labs.shaders 1.0

Item {
    id: root

    function burn(theBug) {
        root.x = theBug.x + theBug.width/2 - root.width/2;
        root.y = theBug.y + theBug.height/2 - root.height/2;
        root.scale = 0.2 + theBug.bugSpeed * 0.08
        fireItem.burningColor = 0.1 + Math.random() * 0.4;
        //console.debug(root.scale);
        angleAnimation.restart();
        burnAnimation.restart()
    }

    opacity: 0
    width: burningLightImageSource.width
    height: burningLightImageSource.height

    SequentialAnimation {
        id: burnAnimation
        paused: running ? gamePaused && !mainMenuOn : false
        PropertyAnimation {
            target: root
            property: "opacity"
            to: 1.0
            duration: 1000
            easing.type: Easing.OutQuad
        }
        PauseAnimation { duration: 500 }
        PropertyAnimation {
            target: root
            property: "opacity"
            to: 0
            duration: 1000
            easing.type: Easing.InOutQuad
        }
    }

    ShaderEffectItem {
        id: fireItem
        property variant source: ShaderEffectSource { sourceItem: burningLightImageSource; hideSource: true }

        property real angle;
        property variant origin: Qt.point(0.5, 0.5);
        property real burningColor: 0.5;

        anchors.fill: parent
        rotation: angle * angle * 10;

        NumberAnimation on angle {
            id: angleAnimation
            from: 0
            to: 2*Math.PI
            duration: 5000
            running: false
            paused: running ? gamePaused && !mainMenuOn : false
        }

        fragmentShader: "
        varying highp vec2 qt_TexCoord0;
        uniform highp float qt_Opacity;
        uniform sampler2D source;
        uniform highp float angle;
        uniform highp vec2 origin;
        uniform highp float burningColor;

        void main(void)
        {
            highp vec4 pix = texture2D(source, qt_TexCoord0.st);
            highp float dist = length(vec2(qt_TexCoord0.x - origin.x , qt_TexCoord0.y - origin.y));
            highp vec4 color = vec4(burningColor/dist, 0.10/dist, 0.05/dist, 0.05/dist);
            // Animate and keep effect inside a suitable range
            color *= sin(angle) * (0.5 - dist);
            gl_FragColor = qt_Opacity * (pix + color);
        }
        "
    }
}
