import QtQuick 1.1

QtObject {
    id: root

    // Add one new bug into world
    function createNewBug(bugType) {
        var newX, newY;

        // top, right, left
        // Note: no bottom as finger is in front
        var side = Math.random() * 3;
        if (Math.floor(side) == 0) {
            newX = Math.random() * worldWidth;
            newY = -100;
        } else if (Math.floor(side) == 1) {
            newX = worldWidth + 60;
            newY = Math.random() * worldHeight * 0.8;
        } else {
            newX = -100;
            newY = Math.random() * worldHeight * 0.8;
        }

        var worldCenterX = worldWidth/2 - 32;
        var worldCenterY = worldHeight/2 - 32;
        var distX = newX - worldCenterX;
        var distY = newY - worldCenterY;
        var newDistance = Math.sqrt(distX*distX + distY*distY)
        var newRotation = Math.atan(Math.abs((distY) / (distX)));

        newRotation *= (180/Math.PI);
        if (distX < 0 && distY < 0) newRotation += 90;
        if (distX >= 0 && distY >= 0) newRotation += 270;
        if (distX < 0 && distY >= 0) newRotation = (90 - newRotation);
        if (distX >= 0 && distY < 0) newRotation = (180 + (90-newRotation));

        /*
        console.debug("newX " + newX);
        console.debug("newY " + newY);
        console.debug("worldCenterX " + worldCenterX);
        console.debug("worldCenterY " + worldCenterY);
        console.debug("distX " + distX);
        console.debug("distY " + distY);
        console.debug("newRotation " + newRotation);
        */

        var component = Qt.createComponent("Bug.qml");
        if (component.status == Component.Ready) {
            var bug = component.createObject(mainViewItem.bugsContainer,
                                             {
                                                 "bugX": newX,
                                                 "bugY": newY,
                                                 "bugType": bugType,
                                                 "bugDistance": newDistance,
                                                 "bugRotation": newRotation
                                             });
            bugsModel.append({"bugItem": bug});
        }
    }

    function createNewWorm() {
        var newX, newY;
        var worldCenterX = worldWidth/2 - 32;
        var worldCenterY = worldHeight/2 - 32;

        var validPos = false;

        // Make sure position is OK, not on top of cookie
        while (!validPos) {
            newX = 32 + Math.random() * (worldWidth - 100);
            newY = 32 + Math.random() * (worldHeight - 180);
            if (newX > worldCenterX - 100 &&
                    newX < worldCenterX + 100 &&
                    newY > worldCenterY - 100 &&
                    newY < worldCenterY + 100 ) {
                validPos = false;
            } else {
                validPos = true;
            }
        }

        var component = Qt.createComponent("Worm.qml");
        if (component.status == Component.Ready) {
            var bug = component.createObject(mainViewItem.bugsContainer,
                                             {
                                                 "x": newX,
                                                 "y": newY,
                                                 "bugType": "worm"
                                             });
            bugsModel.append({"bugItem": bug});
        }
    }

    // Start new game
    function startNewGame() {

        // Clean all bugs
        for (var i=0; i<bugsModel.count; i++) {
            var tempItem = bugsModel.get(i).bugItem;
            tempItem.destroy();
        }
        bugsModel.clear();

        // Reset all properties
        currentGameSpeed = startingGameSpeed;
        gameScore = 0;
        gameFinalScore = 0;
        gameTime = 0;
        pauseMenu.resetMenuPosition();
        pauseMenu.setPaused(false);

        world.initMagnifierPosition();

        var music = gameField + nightMode;
        backgroundMusic.source = "sounds/music" + music + ".mp3"

        // Create new bugs for starters
        for (var j=0; j<3; j++) {
            createNewBug("ant");
        }
        if (gameField == 1) {
            createNewBug("ladybug");
        }
        if (gameField == 3) {
            createNewBug("beetle");
        }

        mainMenuOn = false;
        gameOn = true;
    }

    // Game has ended, bug got a cookie
    function gameOver() {
        gameFinalScore = gameScore + gameTime;
        scoreMenu.startScoreAnimation();
        gameOn = false;
        saveHighScore(gameField + nightMode, gameFinalScore);
        playSound("win");
        world.initMagnifierPosition();
        loadHighScores();
    }

    // Player switches in ScoreMenu from game to main menu
    function backToMainMenu() {
        mainMenuOn = true;
        screen.allowSwipe = true;

        // Clean all bugs
        for (var i=0; i<bugsModel.count; i++) {
            var tempItem = bugsModel.get(i).bugItem;
            tempItem.destroy();
        }
        bugsModel.clear();
    }

    // Increase score
    function addScore(score) {
        gameScore += score;
        playSound("burn");
    }

    // Initialize and load highscores from local DB
    function loadHighScores() {

        var db = openDatabaseSync("SmokeTheBugsScores", "1.0", "", 100);
        db.transaction(function(tx) {

                           // Enable to clean highscores
                           //tx.executeSql('DROP TABLE IF EXISTS Scores');

                           // These are done only in first run
                           tx.executeSql('CREATE TABLE IF NOT EXISTS Scores(level NUMBER, score NUMBER, PRIMARY KEY(level))');
                           var rs = tx.executeSql('SELECT score FROM Scores ORDER BY level');
                           if (rs.rows.length === 0) {
                               tx.executeSql('INSERT OR REPLACE INTO Scores VALUES(1, 0)');
                               tx.executeSql('INSERT OR REPLACE INTO Scores VALUES(2, 0)');
                               tx.executeSql('INSERT OR REPLACE INTO Scores VALUES(3, 0)');
                               tx.executeSql('INSERT OR REPLACE INTO Scores VALUES(4, 0)');
                           }

                           rs = tx.executeSql('SELECT score FROM Scores ORDER BY level');
                           highScoreLevel1 = rs.rows.item(0).score;
                           highScoreLevel2 = rs.rows.item(1).score;
                           highScoreLevel3 = rs.rows.item(2).score;
                           highScoreLevel4 = rs.rows.item(3).score;
                       });
    }

    // Save new highscore if it's better than current one
    function saveHighScore(level, score) {

        var db = openDatabaseSync("SmokeTheBugsScores", "1.0", "", 100);

        // Check if best score is smaller than achieved one
        var bestScore = 0;
        db.transaction(function(tx) {
                           var rs = tx.executeSql('SELECT score FROM Scores WHERE level=?', level);
                           bestScore = rs.rows.item(0).score;
                       });
        if (bestScore < score) {
            var dataStr = "INSERT OR REPLACE INTO Scores VALUES(?, ?)";
            var data = [level, score];
            db.transaction(function(tx) {
                               tx.executeSql(dataStr, data);
                           });
        }
    }

    // Return the achieved level based  on total score
    function getTotalLevel(totScore) {

        if (totScore < 400) {
            return 1;
        } else if (totScore < 800) {
            return 2;
        } else if (totScore < 1200) {
            return 3;
        } else if (totScore < 1600) {
            return 4;
        } else if (totScore < 2000) {
            return 5;
        } else if (totScore < 2400) {
            return 6;
        } else if (totScore < 2800) {
            return 7;
        } else if (totScore < 3200) {
            return 8;
        } else {
            return 9;
        }
    }
}
