import QtQuick 1.1
import Qt.labs.shaders 1.0

ShaderEffectItem {
    property variant source: ShaderEffectSource { sourceItem: worldItem; hideSource: false; }
    property variant source2: ShaderEffectSource { sourceItem: magnifierGlass; hideSource: true; }
    property real magPosX: (root.x + 27/graphicsScale) / worldItem.width
    property real magPosY: (root.y + 27/graphicsScale) / worldItem.height
    property real worldWidth: worldItem.width
    property real worldHeight: worldItem.height
    property real zoomFactor: mainWindow.graphicsScale * 80.0;

    property real angle
    property bool nightMode: mainWindow.nightMode
    property variant origin: Qt.point(0.5, 0.5)
    // TODO: Should center of light move like this?
    //property variant origin: Qt.point(0.25 + 0.5 * magPosX, 0.75 - 0.5 * magPosY);


    SequentialAnimation on angle {
        loops: Animation.Infinite;
        running: gameOn && !gamePaused
        NumberAnimation  {
            to: Math.PI/2;
            duration: 10000;
            easing.type: Easing.InOutQuad
        }
        NumberAnimation {
            to: 0;
            duration: 10000;
            easing.type: Easing.InOutQuad
        }
    }

    fragmentShader: "
    varying highp vec2 qt_TexCoord0;
    uniform sampler2D source;
    uniform sampler2D source2;
    uniform highp float magPosX;
    uniform highp float magPosY;
    uniform highp float worldWidth;
    uniform highp float worldHeight;
    uniform highp float zoomFactor;

    uniform highp float angle;
    uniform highp vec2 origin;
    uniform bool nightMode;

    highp float getFactor(highp float texAngle, highp float scale)
    {
        return 0.04 + abs(scale*(1.0-abs(6.0*sin(6.0*(angle + texAngle-1.0))) + 5.0*cos(6.0*(angle + texAngle-1.0))));
    }

    void main(void)
    {
        highp vec4 pix = texture2D(source2, qt_TexCoord0.st);
        highp vec2 pixTexCoord = qt_TexCoord0;
        highp float startX = 25.0 / worldWidth;
        highp float startY = 25.0 / worldHeight;
        pixTexCoord.x = startX + magPosX + pixTexCoord.x * zoomFactor / worldWidth;
        pixTexCoord.y = -startY + (1.0 - magPosY) - (1.0 - pixTexCoord.y) * zoomFactor / worldHeight;
        pix = pix.a * texture2D(source, pixTexCoord.xy);

        highp float texAngle;
        texAngle = atan(qt_TexCoord0.y - origin.y, qt_TexCoord0.x - origin.x);
        highp float radius = length(vec2(qt_TexCoord0.x - origin.x , qt_TexCoord0.y - origin.y));
        highp float factor2 = getFactor(texAngle, 0.003*(sin(angle)+2.0));

        // Nightmode is greenish
        lowp float nightColor = nightMode ? 0.5 : 1.0;
        highp vec4 color=vec4(nightColor, 1.0, nightColor, factor2/radius);

        gl_FragColor =  pix * vec4(color.rgb*color.a, 1.0) * 10.0;
    }
    "
}
