import QtQuick 1.1

Item {
    id: root

    property alias helpButtonToggled: helpButton.toggled
    property alias highScoresButtonToggled: highScoresButton.toggled
    anchors.fill: parent

    Behavior on opacity {
        NumberAnimation { duration: 400 }
    }

    // Not using real night shader here for better swith performance and no minimize issues
    Rectangle {
        id: fakeNightModeHider
        anchors.fill: parent
        color: "#000000"
        opacity: nightMode ? 0.8 : 0
        Behavior on opacity {
            NumberAnimation { duration: 200 }
        }
    }

    MouseArea {
        anchors.fill: parent
        onPressed: {}
    }

    Image {
        width: parent.width - 20;
        y: parent.height * 0.15
        anchors.horizontalCenter: parent.horizontalCenter
        fillMode: Image.PreserveAspectFit
        smooth: true
        source: "images/logo.png"
    }

    Item {
        id: menuArea
        width: parent.width
        height: root.height / 2
        y: root.height - menuArea.height

        Column {
            width: parent.width * 0.94
            anchors.horizontalCenter: parent.horizontalCenter
            spacing: 6
            MySwitch {
                textOff: "Grass"
                textOn: "Sand"
                onOnChanged: {
                    gameField = on ? 3 : 1;
                }
            }
            MySwitch {
                textOff: "Day"
                textOn: "Night"
                onOnChanged: {
                    nightMode = on;
                }
            }
            MyButton {
                text: "Start New Game"
                onClicked: {
                    coreLib.startNewGame();
                }
            }
        }

        Item {
            width: parent.width * 0.94
            height: highScoresButton.height
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 8
            MyButton {
                id: highScoresButton
                anchors.left: parent.left
                width: parent.width * 0.45
                height: mainView.height * 0.075
                text: "High Scores"
                toggleButton: true
                disabled: helpButton.toggled
            }
            MyButton {
                id: helpButton
                anchors.right: parent.right
                width: parent.width * 0.45
                height: mainView.height * 0.075
                text: "Help"
                toggleButton: true
                disabled: highScoresButton.toggled
            }
        }
    }
}
