import QtQuick 1.1
import QtMultimediaKit 1.1

Item {
    id: root

    property alias bugsContainer: world.bugsContainer

    // *** Sound effects ***
    function playSound(sound) {
        if (!soundsOn) return;

        // TODO: add sounds
        if (sound == "button") buttonSound.play();
        else if (sound == "burn") {
            // Simultanious sounds + random
            // TODO: Nicer way to do this without arrays?
            var randBurnSound = Math.floor(Math.random() * 3);
            if (randBurnSound == 0 && !burnSound.playing) {
                burnSound.play();
            } else if (randBurnSound == 1 && !burnSound2.playing) {
                burnSound2.play();
            } else if (randBurnSound == 2 && !burnSound3.playing) {
                burnSound3.play();
            } else if (!burnSound.playing) {
                burnSound.play();
            } else {
                burnSound2.play();
            }
        } else if (sound == "win") {
            winSound.play();
        }
    }

    Component.onCompleted: {
        world.initMagnifierPosition();
        coreLib.loadHighScores();
        // When world has been loaded, animate app to visible
        mainView.animateAppVisible();
    }

    CoreLib {
        id: coreLib
    }

    ListModel {
        id: bugsModel
    }

    World {
        id: world
        width: worldWidth
        height: worldHeight
    }

    PauseMenu {
        id: pauseMenu
        opacity: gameOn
    }

    ScoreMenu {
        id: scoreMenu
        visible: !gameOn && !mainMenuOn
    }

    MainMenu {
        id: mainMenu
        opacity: !gameOn && mainMenuOn
    }

    TopPanel {
        id: topPanel
        anchors.top: parent.top
        opacity: !gameOn || gamePaused
    }

    LoaderHelper {
        id: helpMenuLoader
        source: mainMenu.helpButtonToggled ? "HelpMenu.qml" : ""
    }
    LoaderHelper {
        id: highScoreMenuLoader
        source: mainMenu.highScoresButtonToggled ? "HighScoreMenu.qml" : ""
    }

    // Disable these when sounds are not supported

    Audio {
         id: backgroundMusic
         playing: soundsOn && !mainMenuOn
         paused: gamePaused
         volume: 0.4
         onStatusChanged: {
             if (status == Audio.EndOfMedia) {
                 backgroundMusic.play();
             }
         }
    }

    SoundEffect {
        id: buttonSound
        source: "sounds/button.wav"
    }
    SoundEffect {
        id: burnSound
        source: "sounds/fire1.wav"
    }
    SoundEffect {
        id: burnSound2
        source: "sounds/fire2.wav"
    }
    SoundEffect {
        id: burnSound3
        source: "sounds/fire3.wav"
    }
    SoundEffect {
        id: winSound
        source: "sounds/win.wav"
    }

}
