import QtQuick 1.1
import Qt.labs.shaders 1.0

ShaderEffectItem {
    id: worldNightItem
    property variant source: ShaderEffectSource { sourceItem: nightEffectArea; hideSource: false; live: true }
    // Lights: positionX, positionY, strength
    // Magnifier light, few lights for bugs
    property variant lightM: Qt.vector3d(magnifier.centerPosX, 1.0 - magnifier.centerPosY, 1.0);
    property variant light1: Qt.vector3d(light1Pos.x, light1Pos.y, light1Volume);
    property variant light2: Qt.vector3d(light2Pos.x, light2Pos.y, light2Volume);

    meshResolution: Qt.size(4,8)

    vertexShader: "
    attribute lowp vec4 qt_Vertex;
    attribute lowp vec2 qt_MultiTexCoord0;
    uniform highp mat4 qt_ModelViewProjectionMatrix;
    varying lowp vec2 qt_TexCoord0;
    uniform highp vec3 lightM;
    uniform highp vec3 light1;
    uniform highp vec3 light2;
    varying highp float v_darkness;
    void main() {
        qt_TexCoord0 = qt_MultiTexCoord0;
        gl_Position = qt_ModelViewProjectionMatrix * qt_Vertex;

        highp vec2 pixPos = qt_TexCoord0.st;
        lowp float darkF = 0.9;
        darkF -= (0.3 - min(0.3, ((lightM.x - pixPos.x)*(lightM.x - pixPos.x)*0.8 + (lightM.y - pixPos.y)*(lightM.y - pixPos.y)*2.0))) * lightM.z;
        lowp float darkF2;
        darkF2 = (0.6 - min(0.6, ((light1.x - pixPos.x)*(light1.x - pixPos.x)*0.5 + (light1.y - pixPos.y)*(light1.y - pixPos.y)))) * light1.z;
        lowp float darkF3;
        darkF3 = (0.6 - min(0.6, ((light2.x - pixPos.x)*(light2.x - pixPos.x)*0.5 + (light2.y - pixPos.y)*(light2.y - pixPos.y)))) * light2.z;
        v_darkness = darkF-darkF2-darkF3;
    }
    "

    fragmentShader: "
    varying highp vec2 qt_TexCoord0;
    uniform highp float qt_Opacity;
    uniform sampler2D source;
    varying highp float v_darkness;

    void main(void)
    {
        highp vec4 color = vec4(0.6 - v_darkness, 0.0, 0.0, v_darkness);
        gl_FragColor = qt_Opacity * color;
    }
    "
}
