import QtQuick 1.1
import com.nokia.meego 1.0

Item {
    id: root

    property int movementY
    // How many pixels bottom panel is from screen bottom
    property int swipeAreaHeight: 20
    // 1 = menu closed, 0 = menu open
    property real menuPosition

    function resetMenuPosition() {
        bottomArea.y = root.height
    }

    function setPaused(status) {
        gamePaused = status;
        screen.allowSwipe = status;
    }

    anchors.fill: parent

    Behavior on opacity {
        NumberAnimation { duration: 200 }
    }

    Item {
        id: pausedContainer

        anchors.fill: parent
        opacity: gamePaused

        Rectangle {
            anchors.fill: parent
            color: "#000000"
            opacity: nightMode ? 1.0 : 0.6
        }

        Text {
            anchors.centerIn: parent
            font.pixelSize: fontSizeXL
            color: "#ffffff"
            style: Text.Outline
            styleColor: "#000000"
            text: "Paused"
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                closeMenuAnimation.restart();
                setPaused(false);
            }
        }
    }

    // This part moves from bottom to up
    Rectangle {
        id: bottomArea

        width: parent.width
        height: endGameButton.height + 32
        y: parent.height
        color: "#000000"
        MouseArea {
            anchors.fill: parent
            anchors.topMargin: -swipeAreaHeight
            onPositionChanged: {
                var movement = root.mapFromItem(bottomArea, mouseX, mouseY);
                var maxHeight = root.height - bottomArea.height;
                var minHeight = root.height;
                movementY = Math.max(Math.min(minHeight, movement.y), maxHeight);
                menuPosition = (maxHeight - movementY) / (maxHeight - minHeight);

                //console.debug(menuPosition);

                bottomArea.y = movementY;

                if (movementY >= minHeight) {
                    setPaused(false);
                } else if (movementY <= maxHeight) {
                    setPaused(true);
                }
            }
            onReleased: {
                if (menuPosition > 0.5) {
                    closeMenuAnimation.restart();
                    setPaused(false);
                } else {
                    openMenuAnimation.restart();
                    setPaused(true);
                }
            }
        }
        MyButton {
            id: endGameButton
            text: "End Game"
            width: parent.width - 32
            anchors.centerIn: parent
            onClicked: {
                world.initMagnifierPosition();
                mainMenuOn = true;
                gameOn = false;
            }
        }

        Text {
            anchors.right: parent.right
            anchors.bottom: parent.top
            font.pixelSize: fontSizeM
            color: "#ffffff"
            style: Text.Outline
            styleColor: "#000000"
            text: "Menu"
            MouseArea {
                anchors.fill: parent
                //anchors.bottomMargin: -bottomArea.height
                anchors.topMargin: -20
                onClicked: {
                    openMenuAnimation.restart();
                    setPaused(true);
                }
            }
        }

        PropertyAnimation {
            id: closeMenuAnimation
            target: bottomArea
            property: "y"
            to: root.height
            easing.type: Easing.InOutQuad
            duration: 400
        }
        PropertyAnimation {
            id: openMenuAnimation
            target: bottomArea
            property: "y"
            to: root.height - bottomArea.height
            easing.type: Easing.InOutQuad
            duration: 400
        }
    }
}
