import QtQuick 1.1

Item {
    id: root

    property alias bugsContainer: bugsContainer
    property alias burnEffects: burnEffects
    property variant light1Pos: Qt.point(0.0, 0.0);
    property variant light2Pos: Qt.point(0.0, 0.0);
    property real light1Volume: 0.0
    property real light2Volume: 0.0
    property int currentLightInQueue: 0
    property int currentBurnInQueue: 0

    function initMagnifierPosition() {
        magnifier.x = cookieItem.x - 45;
        magnifier.y = cookieItem.y - 45;
    }

    function animateLight1() {
        light1Animation.restart();
    }
    function animateLight2() {
        light2Animation.restart();
    }

    SequentialAnimation {
        id: light1Animation
        paused: running ? gamePaused && !mainMenuOn : false
        PropertyAnimation {
            target: root
            property: "light1Volume"
            to: 1.0
            duration: 1500
            easing.type: Easing.OutElastic
        }
        PropertyAnimation {
            target: root
            property: "light1Volume"
            to: 0
            duration: 2000
            easing.type: Easing.InOutQuad
        }
    }
    SequentialAnimation {
        id: light2Animation
        paused: running ? gamePaused && !mainMenuOn : false
        PropertyAnimation {
            target: root
            property: "light2Volume"
            to: 1.0
            duration: 1500
            easing.type: Easing.OutElastic
        }
        PropertyAnimation {
            target: root
            property: "light2Volume"
            to: 0
            duration: 2000
            easing.type: Easing.InOutQuad
        }
    }

    onHeightChanged: {
        initMagnifierPosition();
    }

    Item {
        id: worldItem
        anchors.fill: parent
        Image {
            id: backgroundImage
            anchors.fill: parent
            smooth: true
            sourceSize: Qt.size(width,height)
            source: "images/background" + gameField + ".jpg"
        }
        Image {
            id: cookieItem
            anchors.centerIn: parent
            smooth: true
            scale: graphicsScale
            source: "images/cookie1.png"
        }
        Item {
            id: bugsContainer
            anchors.fill: parent
        }
        Item {
            id: burnEffects

            function burn(theBug) {
                children[currentBurnInQueue].burn(theBug);
                currentBurnInQueue = currentBurnInQueue < children.length-1 ? ++currentBurnInQueue : 0;
            }
            children: [
                // Add as many as bugs can burn simultaniously
                BurnEffect {},
                BurnEffect {},
                BurnEffect {}
            ]
        }
        Image {
            id: burningLightImageSource
            source: "images/light3.png"
        }
    }

    Item {
        id: nightEffectArea
        anchors.fill: parent
    }

    Loader {
        source: nightMode && !mainMenuOn ? "NightEffect.qml" : ""
        anchors.fill: nightEffectArea
        // Hide when application is minimized
        visible: isTopped
    }

    Magnifier {
        id: magnifier
        visible: gameOn && !gamePaused
    }

    Text {
        id: scoreTextItem
        anchors.top: parent.top
        anchors.topMargin: 8
        anchors.left: parent.left
        anchors.leftMargin: 16
        text: gameScore
        font.pixelSize: fontSizeXL
        color: "#ffffff"
        style: Text.Outline
        styleColor: "#000000"
        opacity: gameOn
    }
    Text {
        id: timeTextItem
        anchors.top: parent.top
        anchors.topMargin: 8
        anchors.right: parent.right
        anchors.rightMargin: 16
        text: {
            var min = Math.floor(gameTime/60);
            var sec = gameTime%60
            if (sec < 10) sec = "0" + sec;
            return min + ":" + sec;
        }
        font.pixelSize: fontSizeXL
        color: "#ffffff"
        style: Text.Outline
        styleColor: "#000000"
        opacity: gameOn
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onPositionChanged: {
            var maxX = worldItem.width - magnifier.width * 0.7;
            var minX = -magnifier.width * 0.3;
            var posX = mouse.x - magnifier.width * 0.7 + magnifier.y * 0.04 + (20 / graphicsScale)
            var maxY = worldItem.height - magnifier.height * 0.5;
            var minY = -magnifier.height * 0.2;
            var posY = mouse.y - magnifier.height + magnifier.y * 0.15 + (30 / graphicsScale)
            magnifier.x = Math.max(minX, Math.min(posX, maxX));
            magnifier.y = Math.max(minY, Math.min(posY, maxY));
        }
    }

    // This is used to check if magnifier is on top of a bug, heating it
    Timer {
        id: checkHeatingTimer
        running: gameOn && !gamePaused
        repeat: true
        interval: 100
        onTriggered: {
            var magCenterX = 95;
            var magCenterY = 90;
            var tempItem = bugsContainer.childAt(magnifier.x + magCenterX, magnifier.y + magCenterY);
            if (tempItem != null) {
                tempItem.heating();
            }
        }
    }
    // This creates new bugs into world
    Timer {
        id: newBugsTimer
        running: gameOn && !gamePaused
        repeat: true
        interval: 200
        onTriggered: {
            // TODO: Add a bit more sense for speeding up and creating bugs
            currentGameSpeed *= 0.999;
            var newBugTime = Math.random() * currentGameSpeed;
            if (newBugTime < 0.8) {
                var whichBug = Math.random() * 100;
                if (whichBug < 10) {
                    if (gameField == 1) {
                        coreLib.createNewBug("ladybug");
                    } else {
                        coreLib.createNewBug("beetle");
                    }
                } else if (whichBug < 60 && gameField == 1) {
                    coreLib.createNewWorm();
                } else if (whichBug < 20 && gameField == 3 && nightMode) {
                    coreLib.createNewBug("crab");;
                } else {
                    coreLib.createNewBug("ant");
                }
            }
        }
    }

    Timer {
        id: gameTimeTimer
        running: gameOn && !gamePaused
        repeat: true
        interval: 1000
        onTriggered: {
            gameTime++
        }
    }

}
